==> haskell-data-textual-0.3.0.3-359-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-textual
version:              0.3.0.3
visibility:           public
id:                   data-textual-0.3.0.3-K1TS8isGpEQ3ybssfqoZvy
key:                  data-textual-0.3.0.3-K1TS8isGpEQ3ybssfqoZvy
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-textual
synopsis:             Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.

category:             Data, Text
abi:                  22b3795db08d63e3d1ad377bb908c019
exposed:              True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-textual
hs-libraries:         HSdata-textual-0.3.0.3-K1TS8isGpEQ3ybssfqoZvy
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    parsers-0.12.12-7AcapIsjct66ZeSNLGF65t text-2.0.2
    text-latin1-0.3.1-GMG7oDx3oXmFloebXrHwze
    text-printer-0.5.0.2-6NjVX7FVAdDEq5PcuzX8GI

haddock-interfaces:
    /usr/share/doc/haskell-data-textual/html/data-textual.haddock

haddock-html:         /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-textual-0.3.0.3-360-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-textual.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-textual
version:              0.3.0.3
visibility:           public
id:                   data-textual-0.3.0.3-GBqYxSIRkAFFxkOKuwI644
key:                  data-textual-0.3.0.3-GBqYxSIRkAFFxkOKuwI644
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-textual
synopsis:             Human-friendly textual representations.
description:
    This package provides an interface for converting between data and its
    (human-friendly) textual representation.

category:             Data, Text
abi:                  bca81dbef08adf6393267e4eaf2facdd
exposed:              True
exposed-modules:
    Data.Textual Data.Textual.Fractional Data.Textual.Integral

import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-textual-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-textual
hs-libraries:         HSdata-textual-0.3.0.3-GBqYxSIRkAFFxkOKuwI644
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    parsers-0.12.12-5DckDyYNV2JEaDynl65IQL text-2.0.2
    text-latin1-0.3.1-8aotpe1rSb74uztVEgj4YN
    text-printer-0.5.0.2-Ec4RRPB9SJlGodiFWaqJF7

haddock-interfaces:
    /usr/share/doc/haskell-data-textual/html/data-textual.haddock

haddock-html:         /usr/share/doc/haskell-data-textual/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
